@@ -1,4 +1,4 @@
-LPDMRSortIdentifyIncompatibleAssignments <- function(performanceTable, assignments, categoriesRanks, criteriaMinMax, majorityRule = "M", incompatibleSetsLimit = 100, largerIncompatibleSetsMargin = 0, alternativesIDs = NULL, criteriaIDs = NULL, solver = "glpk", cplexIntegralityTolerance = NULL, cplexThreads = NULL){
+LPDMRSortIdentifyIncompatibleAssignments <- function(performanceTable, assignments, categoriesRanks, criteriaMinMax, majorityRule = "M", incompatibleSetsLimit = 100, largerIncompatibleSetsMargin = 0, alternativesIDs = NULL, criteriaIDs = NULL){
   
   ## check the input data
   if (!((is.matrix(performanceTable) || (is.data.frame(performanceTable))))) 
@@ -182,77 +182,28 @@ LPDMRSortIdentifyIncompatibleAssignments <- function(performanceTable, assignmen
   else 
     stop(return_codeGLPK(out))
   
-  if (solver == "cplex")
-  {
-    
-    if (!requireNamespace("cplexAPI", quietly = TRUE)) stop("cplexAPI package could not be loaded")
-    
-    cplexOutFile <- tempfile()
-    
-    writeLPGLPK(lp, cplexOutFile)
-    
-    # Open a CPLEX environment
-    env <- cplexAPI::openEnvCPLEX()
-    
-    # Create a problem object
-    prob <- cplexAPI::initProbCPLEX(env)
-    
-    # if (!is.null(cplexTimeLimit))
-    #  cplexAPI::setDblParmCPLEX(env,cplexAPI::CPX_PARAM_TILIM,cplexTimeLimit)
-    
-    if (!is.null(cplexIntegralityTolerance))
-      cplexAPI::setDblParmCPLEX(env,cplexAPI::CPX_PARAM_EPINT,cplexIntegralityTolerance)
-    
-    if (!is.null(cplexThreads))
-      cplexAPI::setDblParmCPLEX(env,cplexAPI::CPX_PARAM_THREADS,cplexThreads)
-    
-    # Read MIP problem from cplexOutFile
-    out <- cplexAPI::readCopyProbCPLEX(env, prob, cplexOutFile, ftype = "LP")
-    
-    # solve the problem
-    if (out == 0)
-      cplexAPI::mipoptCPLEX(env,prob)
-    else
-      stop(out)
-    
-    error <- TRUE
-    
-    if (cplexAPI::getStatCPLEX(env,prob) %in% c(1,5,15,17,19,20,101,102,115,121,123,125,129,130)){
-      solution <- cplexAPI::solutionCPLEX(env,prob)$x
-      
-      varnames <- cplexAPI::getColNameCPLEX(env,prob, 0,length(solution)-1)
-      
-      paro <- "("
-      parc <- ")"
-      
-      error <- FALSE
-    }
-    
-  } else if (solver == "glpk"){
-    
-    solveMIPGLPK(lp)
-    
-    if(mipStatusGLPK(lp)==5){
-      
-      mplPostsolveGLPK(tran, lp, sol = GLP_MIP)
-      
-      solution <- mipColsValGLPK(lp)
-      
-      varnames <- c()
-      
-      for (i in 1:length(solution))
-        varnames <- c(varnames,getColNameGLPK(lp,i))
-      
-      paro <- "["
-      parc <- "]"
-      
-      error <- FALSE
-    }
-  }
-    
-  if (!error){
+  solveMIPGLPK(lp)
   
-   # get size of minimal incompatible assignments set and one such set
+  if(mipStatusGLPK(lp)==5){
+    
+    mplPostsolveGLPK(tran, lp, sol = GLP_MIP)
+    
+    solution <- mipColsValGLPK(lp)
+    
+    varnames <- c()
+    
+    for (i in 1:length(solution))
+      varnames <- c(varnames,getColNameGLPK(lp,i))
+    
+    paro <- "["
+    parc <- "]"
+    
+    error <- FALSE
+  }
+  
+  if (!error){
+    
+    # get size of minimal incompatible assignments set and one such set
     
     minIncompatibleSetsSize <- 0
     
@@ -290,7 +241,7 @@ LPDMRSortIdentifyIncompatibleAssignments <- function(performanceTable, assignmen
       datacontent2a <- paste(datacontent2a, solution[varnames==paste("OnOff",paro,i,parc,sep="")], sep = " ")
     
     datacontent2b <- paste("param PrevOnOffLimit := \n1\t ", minIncompatibleSetsSize, sep ="")
-
+    
     # iterate through acceptes sizes for incompatible assignment sets
     
     incompatibleSetSize <- minIncompatibleSetsSize
@@ -353,79 +304,31 @@ LPDMRSortIdentifyIncompatibleAssignments <- function(performanceTable, assignmen
         else 
           stop(return_codeGLPK(out))
         
-        if (solver == "cplex")
-        {
+        
+        
+        solveMIPGLPK(lp)
+        
+        error <- TRUE
+        
+        if(mipStatusGLPK(lp)==5){
           
-          if (!requireNamespace("cplexAPI", quietly = TRUE)) stop("cplexAPI package could not be loaded")
+          mplPostsolveGLPK(tran, lp, sol = GLP_MIP)
           
-          cplexOutFile <- tempfile()
+          solution <- mipColsValGLPK(lp)
           
-          writeLPGLPK(lp, cplexOutFile)
+          varnames <- c()
           
-          # Open a CPLEX environment
-          env <- cplexAPI::openEnvCPLEX()
+          for (i in 1:length(solution))
+            varnames <- c(varnames,getColNameGLPK(lp,i))
           
-          # Create a problem object
-          prob <- cplexAPI::initProbCPLEX(env)
+          paro <- "["
+          parc <- "]"
           
-          # if (!is.null(cplexTimeLimit))
-          #   cplexAPI::setDblParmCPLEX(env,cplexAPI::CPX_PARAM_TILIM,cplexTimeLimit)
-          
-          if (!is.null(cplexIntegralityTolerance))
-            cplexAPI::setDblParmCPLEX(env,cplexAPI::CPX_PARAM_EPINT,cplexIntegralityTolerance)
-          
-          if (!is.null(cplexThreads))
-            cplexAPI::setDblParmCPLEX(env,cplexAPI::CPX_PARAM_THREADS,cplexThreads)
-          
-          # Read MIP problem from cplexOutFile
-          out <- cplexAPI::readCopyProbCPLEX(env, prob, cplexOutFile, ftype = "LP")
-          
-          # solve the problem
-          if (out == 0)
-            cplexAPI::mipoptCPLEX(env,prob)
-          else
-            stop(out)
-          
-          
-          error <- TRUE
-          
-          if (cplexAPI::getStatCPLEX(env,prob) %in% c(1,5,15,17,19,20,101,102,115,121,123,125,129,130)){
-            
-            solution <- cplexAPI::solutionCPLEX(env,prob)$x
-            
-            varnames <- cplexAPI::getColNameCPLEX(env,prob, 0,length(solution)-1)
-            
-            paro <- "("
-            parc <- ")"
-            
-            error <- FALSE
-          }
-          
-        } else if (solver == "glpk"){
-          
-          solveMIPGLPK(lp)
-          
-          error <- TRUE
-          
-          if(mipStatusGLPK(lp)==5){
-            
-            mplPostsolveGLPK(tran, lp, sol = GLP_MIP)
-            
-            solution <- mipColsValGLPK(lp)
-            
-            varnames <- c()
-            
-            for (i in 1:length(solution))
-              varnames <- c(varnames,getColNameGLPK(lp,i))
-            
-            paro <- "["
-            parc <- "]"
-            
-            error <- FALSE
-          }
+          error <- FALSE
         }
         
         
+        
         if (!error){
           
           # get incompatible assignments set
